import ready from 'Utils/documentReady.js';
import getScrollSize from 'Utils/getScrollSize.js';
import Swiper, { Navigation, Pagination, EffectFade, Autoplay } from 'swiper';
import Accordion from 'accordion-js';

Swiper.use([Navigation, Pagination, EffectFade, Autoplay]);

ready(function() {
  console.log('DOM героически построен!');
  const body = document.querySelector('body');

  // Добавление кастомного свойства с системной шириной скролла
  document.documentElement.style.setProperty('--css-scroll-size', `${getScrollSize()}px`);
  
  const accordion = document.querySelector('.accordion-container');

  if (accordion) {
    new Accordion(accordion, {
      openOnInit: [0],
    });
  }

  
  const stickyHeader = document.querySelector('.page-header');
  const headerOffset = findOffset(stickyHeader);
  
  window.addEventListener('scroll', () => {
    const bodyScrollTop = document.documentElement.scrollTop || document.body.scrollTop;
  
    if (bodyScrollTop > headerOffset.top) {
      stickyHeader.classList.add('fixed');
    } else {
      stickyHeader.classList.remove('fixed');
    }

    document.documentElement.style.setProperty('--header-bottom', `${stickyHeader.getBoundingClientRect().bottom}px`);
  });

  function findOffset(element) {
    let top = 0, left = 0;
  
    do {
      top += element.offsetTop  || 0;
      left += element.offsetLeft || 0;
      element = element.offsetParent;
    } while(element);
  
    return {
      top: top,
      left: left
    };
  }
  
  // Swiper sliders
  new Swiper(".slider-t-1", {
    autoplay: {
      delay: 4000,
      disableOnInteraction: false,
    },
    speed: 1000,
    slidesPerView: 1,
    effect: 'fade',
    navigation: {
      nextEl: ".slider-t-1 .swiper-button-next",
      prevEl: ".slider-t-1 .swiper-button-prev",
    },
    pagination: {
      el: '.slider-t-1 .swiper-pagination',
      type: 'custom',
      renderCustom: function(swiper, current, total) {
        let customPaginationHtml = "";

        for(let i = 0; i < total; i++) {
          const slideTitle = swiper.slides[i].querySelector('.slider-t-1__s-title').textContent;

          if(i == (current - 1)) {
            customPaginationHtml += `
            <button 
              data-slide='${i}'
              class='swiper-pagination-custom-btn swiper-pagination-custom-btn-active'>
                <span class='swiper-pagination-progress'><span></span></span>
                ${slideTitle}
              </button>
            `;
          } else {
            customPaginationHtml += `
            <button 
              data-slide='${i}'
              class='swiper-pagination-custom-btn'>
                <span class='swiper-pagination-progress'><span></span></span>
                ${slideTitle}
            </button>
            `;
          }
        }

        return customPaginationHtml;
      }
    },
    on: {
      init: function(swiper) {
        body.addEventListener('click', (e) => {
          if (e.target.classList.contains('swiper-pagination-custom-btn')) {
            swiper.slideTo(e.target.dataset.slide);
          }
        });
      },
      slideChange: function({pagination, activeIndex, passedParams}) { 
        if (passedParams.autoplay) {
          const acitveDot = pagination.el.children[activeIndex];
          const paginationProgressElem = acitveDot.querySelector('.swiper-pagination-progress span');
          const delay = (passedParams.autoplay.delay ? passedParams.autoplay.delay : 3000) + passedParams.speed;
  
          animate({
            duration: delay,
            timing(timeFraction) {
              return timeFraction;
            },
            draw(progress) {
              paginationProgressElem.style.width = progress * 100 + '%';
            }
          });
  
          function animate({timing, draw, duration}) {
            let start = performance.now();
          
            requestAnimationFrame(function animate(time) {
              let timeFraction = (time - start) / duration;
              if (timeFraction > 1) timeFraction = 1;
          
              let progress = timing(timeFraction);
              draw(progress);
          
              if (timeFraction < 1) {
                requestAnimationFrame(animate);
              }
            });
          }
        }
      },
    }
  });

  new Swiper(".swiper-list .swiper", {
    autoplay: {
      delay: 3000,
      disableOnInteraction: false,
    },
    speed: 1000,
    navigation: {
      nextEl: ".swiper-list .swiper-button-next",
      prevEl: ".swiper-list .swiper-button-prev",
    },
    breakpoints: {
      320: {
        slidesPerView: 'auto',
        spaceBetween: 20,
      },
      480: {
        slidesPerView: 2,
        spaceBetween: 40,
      },
      768: {
        slidesPerView: 3,
        spaceBetween: 40
      },
      992: {
        slidesPerView: 4,
        spaceBetween: 40
      },
      992: {
        slidesPerView: 3,
        spaceBetween: 40
      },
      1677: {
        slidesPerView: 4,
        spaceBetween: 40
      }
    }
  });

  new Swiper(".big-slider", {
    slidesPerView: 1,
    speed: 1000,
    effect: 'fade',
    navigation: {
      nextEl: ".big-slider .swiper-button-next",
      prevEl: ".big-slider .swiper-button-prev",
    },
  });


  const pdgJS = document.querySelector('.pdg-js');

  if (pdgJS && screen.width > 951) {
    const pdgJSTitle = document.querySelector(`${pdgJS.dataset.pdgTarget}`),
          pdgJSListItems = pdgJS.querySelectorAll('.sections-list__i-inner');
    const divider = screen.width > 1199 ? 3 : 2;

    pdgJSFun();

    window.addEventListener('resize', (e) => {
      pdgJSFun();
    });

    function pdgJSFun() {
      const pdgJSLeft = pdgJSTitle.getBoundingClientRect().left;
      
      pdgJSListItems.forEach((item, i) => {
        if (!((i + 1) % divider)) {
          pdgJSListItems[i - (divider - 1)].style.paddingLeft = `${pdgJSLeft}px`;
          pdgJSListItems[i].style.paddingRight = `${pdgJSLeft}px`;
        }
      });
    }
  }


  // Mobile menu
  const mobMenu = document.querySelector(".mob-menu");

  if (mobMenu) {
    const mobMenuTrigger = document.querySelector('.main-nav__toggler');
    
    mobMenu.addEventListener("click", (e) => {
      if (e.target.classList.contains("mob-menu__close")) {
        mobMenuTrigger.classList.remove('burger--close');
        mobMenu.classList.remove('active');
        body.classList.remove('of-h');
      }
    });
  }

  // Map SVG
  const mapSvg = document.getElementById('map-svg');

  if (mapSvg) {
    const {x: leftIndent, y: topIndent} = mapSvg.getBoundingClientRect();
    const paths = mapSvg.querySelectorAll('path');
    const pinsArea = document.getElementById('map-svg__pins');

    paths.forEach(path => {
      const area = path.dataset.area;

      if (area) {
        const areaModal = document.querySelector(`.map-svg__area[data-area='${area}']`);
        let {
              x: pathX,
              y: pathY,
              width: pathWidth,
              height: pathHeight
            } = path.getBoundingClientRect();
  
        pathX = parseInt(pathX) - leftIndent;
        pathY = parseInt(pathY) - topIndent;
        pinsArea.append(createPin(pathX + (pathWidth/2 - 13), pathY + (pathHeight/2 - 13), area));
  
        if (areaModal) {
          const {width: modalWidth, height: modalHeight} = areaModal.getBoundingClientRect();
          const rightPointModal = pathX + leftIndent + pathWidth + 20 + modalWidth;
          
          if (rightPointModal > screen.width) {
            areaModal.style.left = `${pathX - modalWidth - 20}px`;

            if (areaModal.getBoundingClientRect().left < 15) {
              areaModal.style.left = `0`;
            }
          }  else {
            areaModal.style.left = `${pathX + pathWidth + 20}px`;
          }
          areaModal.style.top = `${pathY - (modalHeight/2 - pathHeight/2)}px`;
        }
      }
    });

    body.addEventListener('mouseover', (e) => {
      if (e.target.hasAttribute('data-area')) {
        showHideAreaModal(e.target, "add");
      }
    });

    body.addEventListener('mouseout', (e) => {
      if (e.target.hasAttribute('data-area')) {
        showHideAreaModal(e.target, "remove");
      }
    });

    function showHideAreaModal(target, action) {
      try {
        const area = target.dataset.area;
        const curPin = document.querySelector(`.map-svg__pin[data-area='${area}']`);
        const curModal = document.querySelector(`.map-svg__area[data-area='${area}']`);
        const curPath = document.querySelector(`#map-svg path[data-area='${area}']`);
        
        curPath.classList[action]('hover');
        curPin.classList[action]('hide');
        curModal.classList[action]('active');
      } catch (err) {
        console.error(err);
      }
    }

    function createPin(x, y, area) {
      let screenSize = null;
      const pin = document.createElement('div');
      const correctionsPins = {
        md: {
          smolenskaya: {left: 6, top: 5},
          kaliningradskaya: {left: 5, top: 5},
          murmanskaya: {left: 10, top: 0},
          leningradskaya: {left: 0, top: 2},
          pskovskaya: {left: 5, top: 6},
          novgorodskaya: {left: 7, top: 4},
          tverskaya: {left: 6, top: 6},
          bryanskaya: {left: 9, top: 8},
          moskovskaya: {left: 6, top: 6},
          voronezhskaya: {left: 8, top: 6},
          yaroslavskaya: {left: 9, top: 6},
          ryazanskaya: {left: 8, top: 4},
          ivanovskaya: {left: 8, top: 6},
          vladimirskaya: {left: 5, top: 6},
          lipetskaya: {left: 8, top: 3},
          nizhegorodskaya: {left: 4, top: 4},
          mordoviya: {left: 6, top: 4},
          'mariy-el': {left: 9, top: 6},
          chuvashiya: {left: 7, top: 4},
          samarskaya: {left: 6, top: 6},
          kirovskaya: {left: 4, top: 8},
          arkhangelskaya: {left: 4, top: 2},
          komi: {left: 0, top: 5},
          krym: {left: 5, top: 3},
          rostovskaya: {left: 4, top: 4},
          kalmykia: {left: 11, top: 4},
          dagestan: {left: 12, top: 0},
          'karachayevo-cherkesiya': {left: 6, top: 2},
          'kabardino-balkariya': {left: 6, top: 4},
          omskaya: {left: 10, top: 2},
          permskiy: {left: 10, top: 2},
          sverdlovskaya: {left: 12, top: 10},
          bashkortostan: {left: 2, top: 0},
          orenburgskaya: {left: 0, top: -2},
          chelyabinskaya: {left: 16, top: 0},
          kurganskaya: {left: 6, top: 4},
          'khanty-mansiyskiy': {left: -10, top: 10},
          'yamalo-nenetskiy': {left: 10, top: 25},
          kemerovskaya: {left: 6, top: -2},
          tyva: {left: 22, top: 0},
          buryatiya: {left: 35, top: -8},
          zabaykalskaya: {left: 20, top: 15},
          amurskaya: {left: 15, top: 0},
          primorskaya: {left: 10, top: 5},
          sakhalinskaya: {left: 5, top: 0},
          kamchatskaya: {left: 18, top: -25},
        },
        xl: {
          smolenskaya: {left: 4, top: 2},
          kaliningradskaya: {left: 3, top: 4},
          murmanskaya: {left: 7, top: 0},
          leningradskaya: {left: -6, top: -2},
          pskovskaya: {left: 5, top: 0},
          novgorodskaya: {left: 6, top: 0},
          tverskaya: {left: 4, top: 4},
          bryanskaya: {left: 6, top: 4},
          moskovskaya: {left: 4, top: 2},
          voronezhskaya: {left:6, top: 4},
          yaroslavskaya: {left: 8, top: 4},
          ryazanskaya: {left: 5, top: 2},
          ivanovskaya: {left: 6, top: 2},
          vladimirskaya: {left: 3, top: 6},
          lipetskaya: {left: 6, top: 3},
          nizhegorodskaya: {left: 2, top: 0},
          mordoviya: {left: 1, top: 3},
          'mariy-el': {left: 5, top: 4},
          chuvashiya: {left: 5, top: 2},
          samarskaya: {left: 4, top: 2},
          kirovskaya: {left: 0, top: 8},
          arkhangelskaya: {left: -4, top: -6},
          komi: {left: -4, top: -6},
          krym: {left: 1, top: 0},
          rostovskaya: {left: 0, top: 0},
          kalmykia: {left: 8, top: 0},
          dagestan: {left: 10, top: 0},
          'karachayevo-cherkesiya': {left: 3, top: 1},
          'kabardino-balkariya': {left: 4, top: 0},
          permskiy: {left: 5, top: 0},
          sverdlovskaya: {left: 15, top: 10},
          bashkortostan: {left: -5, top: 0},
          orenburgskaya: {left: -5, top: -10},
          chelyabinskaya: {left: 15, top: -4},
          kurganskaya: {left: 0, top: 0},
          'khanty-mansiyskiy': {left: -15, top: 15},
          'yamalo-nenetskiy': {left: 15, top: 35},
          kemerovskaya: {left: 2, top: -5},
          tyva: {left: 25, top: 0},
          buryatiya: {left: 45, top: -8},
          zabaykalskaya: {left: 25, top: 15},
          amurskaya: {left: 20, top: 0},
          primorskaya: {left: 10, top: 5},
          sakhalinskaya: {left: 5, top: 0},
          kamchatskaya: {left: 18, top: -55},
        },
        xxl: {
          kaliningradskaya: {left: -4, top: -3},
          murmanskaya: {left: 5, top: 0},
          leningradskaya: {left: -6, top: 0},
          pskovskaya: {left: -4, top: -6},
          novgorodskaya: {left: 0, top: -8},
          tverskaya: {left: 0, top: -4},
          bryanskaya: {left: 0, top: -4},
          moskovskaya: {left: -2, top: -4},
          yaroslavskaya: {left: 2, top: -3},
          ryazanskaya: {left: 1, top: -7},
          ivanovskaya: {left: 2, top: -5},
          vladimirskaya: {left: -3, top: -2},
          lipetskaya: {left: 0, top: -8},
          nizhegorodskaya: {left: -5, top: -9},
          mordoviya: {left: -4, top: -6},
          'mariy-el': {left: 2, top: -5},
          chuvashiya: {left: 0, top: -6},
          samarskaya: {left: -2, top: -7},
          kirovskaya: {left: -2, top: 0},
          arkhangelskaya: {left: -4, top: -6},
          komi: {left: -4, top: -6},
          krym: {left: -4, top: -8},
          rostovskaya: {left: -8, top: -8},
          kalmykia: {left: 6, top: -4},
          dagestan: {left: 8, top: -12},
          'karachayevo-cherkesiya': {left: -3, top: -9},
          'kabardino-balkariya': {left: 0, top: -9},
          sverdlovskaya: {left: 15, top: 0},
          bashkortostan: {left: -15, top: -5},
          orenburgskaya: {left: -12, top: -10},
          chelyabinskaya: {left: 4, top: -4},
          kurganskaya: {left: -7, top: -4},
          'khanty-mansiyskiy': {left: -35, top: 8},
          'yamalo-nenetskiy': {left: 25, top: 45},
          kemerovskaya: {left: -2, top: -5},
          tyva: {left: 15, top: -8},
          buryatiya: {left: 55, top: -8},
          zabaykalskaya: {left: 35, top: 15},
          amurskaya: {left: 20, top: -15},
          primorskaya: {left: 7, top: 0},
          sakhalinskaya: {left: 4, top: 0},
          kamchatskaya: {left: 25, top: -75},
        },
      };

      if (screen.width >= 1677) {
        screenSize = 'xxl';
      } else if (screen.width >= 1200) {
        screenSize = 'xl';
      } else if (screen.width >= 768) {
        screenSize = 'md';
      } else {

      }

      pin.className = 'map-svg__pin';
      pin.style = `
        position: absolute;
        left: ${correctionsPins[screenSize][area] ? x + correctionsPins[screenSize][area].left : x}px;
        top: ${correctionsPins[screenSize][area] ? y + correctionsPins[screenSize][area].top : y}px;
      `;
      if (area) {
        pin.dataset.area = area;
      }

      return pin;
    }
  }

});

// import $ from 'jquery'; // Перед использованием установить как зависимость
// $(function() {
//   console.log('jQuery героически сработал!');
// });
